@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -252,12 +252,23 @@ QString Budget::loadFile(QString filename, QString &errors) {
 								}
 								case TRANSACTION_TYPE_INCOME: {
 									incomes.append((Income*) trans);
+									if(((Income*) trans)->security()) ((Income*) trans)->security()->dividends.append((Income*) trans);
 									break;
 								}
 								case TRANSACTION_TYPE_EXPENSE: {
 									expenses.append((Expense*) trans);
 									break;
 								}
+								case TRANSACTION_TYPE_SECURITY_BUY: {
+									securityTransactions.append((SecurityBuy*) trans);
+									((SecurityBuy*) trans)->security()->transactions.append((SecurityBuy*) trans);
+									break;
+								}
+								case TRANSACTION_TYPE_SECURITY_SELL: {
+									securityTransactions.append((SecuritySell*) trans);
+									((SecuritySell*) trans)->security()->transactions.append((SecuritySell*) trans);
+									break;
+								}
 								default: {}
 							}
 							transactions.append(trans);
@@ -370,14 +381,14 @@ QString Budget::loadFile(QString filename, QString &errors) {
 	return QString::null;
 }
 
-QString Budget::saveFile(QString filename) {
+QString Budget::saveFile(QString filename, mode_t perms) {
 	
 	QFileInfo info(filename);
 	if(info.isDir()) {
 		return i18n("File is a directory");
 	}
 
-	KSaveFile ofile(filename, 0600);
+	KSaveFile ofile(filename, (int) perms);
 	if(ofile.status()) {
 		ofile.abort();
 		return i18n("Couldn't open file for writing");
@@ -626,6 +637,7 @@ void Budget::removeSplitTransaction(SplitTransaction *split, bool keep) {
 			case TRANSACTION_TYPE_INCOME: {
 				incomes.setAutoDelete(false);
 				incomes.removeRef((Income*) trans);
+				if(((Income*) trans)->security()) ((Income*) trans)->security()->dividends.removeRef((Income*) trans);
 				incomes.setAutoDelete(true);
 				break;
 			}
@@ -635,7 +647,16 @@ void Budget::removeSplitTransaction(SplitTransaction *split, bool keep) {
 				transfers.setAutoDelete(true);
 				break;
 			}
-			default: {}
+			case TRANSACTION_TYPE_SECURITY_BUY: {}
+			case TRANSACTION_TYPE_SECURITY_SELL: {
+				SecurityTransaction *sectrans = (SecurityTransaction*) trans;
+				sectrans->security()->removeQuotation(sectrans->date(), true);
+				securityTransactions.setAutoDelete(false);
+				sectrans->security()->transactions.removeRef(sectrans);
+				securityTransactions.removeRef(sectrans);
+				securityTransactions.setAutoDelete(true);
+				break;
+			}
 		}
 	}
 	if(keep) splitTransactions.setAutoDelete(false);
@@ -811,8 +832,7 @@ void Budget::transactionDateModified(Transaction *t, const QDate &olddate) {
 		case TRANSACTION_TYPE_SECURITY_BUY: {}
 		case TRANSACTION_TYPE_SECURITY_SELL: {
 			SecurityTransaction *tr = (SecurityTransaction*) t;
-			tr->security()->transactions.removeRef(tr);
-			tr->security()->transactions.inSort(tr);
+			if(tr->security()->transactions.removeRef(tr)) tr->security()->transactions.inSort(tr);
 			securityTransactions.setAutoDelete(false);
 			if(securityTransactions.removeRef(tr)) securityTransactions.inSort(tr);
 			securityTransactions.setAutoDelete(true);
