@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -107,7 +107,7 @@ class Budget {
 		~Budget();
 
 		QString loadFile(QString filename, QString &errors);
-		QString saveFile(QString filename);
+		QString saveFile(QString filename, mode_t perms = 0600);
 		
 		void clear();
 
