@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson                                 *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
  *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -45,7 +45,7 @@ class EditScheduledTransactionDialog : public KDialogBase {
 		
 	public:
 		
-		EditScheduledTransactionDialog(bool extra_parameters, int transaction_type, Security *security, Budget *budg, QWidget *parent, QString title, Account *account = NULL);
+		EditScheduledTransactionDialog(bool extra_parameters, int transaction_type, Security *security, bool select_security, Budget *budg, QWidget *parent, QString title, Account *account = NULL);
 
 		bool checkAccounts();
 		void setTransaction(Transaction *trans);
@@ -53,9 +53,9 @@ class EditScheduledTransactionDialog : public KDialogBase {
 		ScheduledTransaction *createScheduledTransaction();
 		bool modifyScheduledTransaction(ScheduledTransaction *strans);
 		bool modifyTransaction(Transaction *trans, Recurrence *&rec);
-		static ScheduledTransaction *newScheduledTransaction(int transaction_type, Budget *budg, QWidget *parent, Security *security = NULL, Account *account = NULL, bool extra_parameters = false);
-		static bool editScheduledTransaction(ScheduledTransaction *strans, QWidget *parent, bool extra_parameters = false);
-		static bool editTransaction(Transaction *trans, Recurrence *&rec,  QWidget *parent, bool extra_parameters = false);
+		static ScheduledTransaction *newScheduledTransaction(int transaction_type, Budget *budg, QWidget *parent, Security *security = NULL, bool select_security = false, Account *account = NULL, bool extra_parameters = false);
+		static bool editScheduledTransaction(ScheduledTransaction *strans, QWidget *parent, bool select_security = true, bool extra_parameters = false);
+		static bool editTransaction(Transaction *trans, Recurrence *&rec,  QWidget *parent, bool select_security = true, bool extra_parameters = false);
 
 	protected slots:
 
