@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -40,7 +40,6 @@ class AssetsAccount;
 class IncomesAccount;
 class ExpensesAccount;
 class KLineEdit;
-class ValueSpinBox;
 class KDateEdit;
 class KComboBox;
 class QPushButton;
@@ -50,6 +49,7 @@ class KJanusWidget;
 class QRadioButton;
 class TransactionListWidget;
 class KAction;
+class KSelectAction;
 class KToggleAction;
 class KRecentFilesAction;
 class QPopupMenu;
@@ -59,7 +59,7 @@ class Expense;
 class Income;
 class Transfer;
 class ConfirmScheduleListViewItem;
-class KDoubleSpinBox;
+class EqonomizeValueEdit;
 class KTextEdit;
 class Security;
 class ReinvestedDividend;
@@ -67,10 +67,17 @@ class SecurityTrade;
 class QSpinBox;
 class QTabWidget;
 class EqonomizeMonthSelector;
-class ValueSpinBox;
 class QVBoxLayout;
 class KToolBar;
 
+typedef enum {
+	INITIAL_PERIOD_CURRENT_MONTH,
+	INITIAL_PERIOD_CURRENT_YEAR,
+	INITIAL_PERIOD_CURRENT_WHOLE_MONTH,
+	INITIAL_PERIOD_CURRENT_WHOLE_YEAR,
+	INITIAL_PERIOD_LAST
+} InitialPeriod;
+
 class Eqonomize : public KMainWindow {
 	
 	Q_OBJECT
@@ -117,8 +124,8 @@ class Eqonomize : public KMainWindow {
 		bool editTransaction(Transaction *trans);
 		bool removeScheduledTransaction(ScheduledTransaction *strans);
 		bool removeOccurrence(ScheduledTransaction *strans, const QDate &date);
-		bool newScheduledTransaction(int transaction_type, Security *security = NULL);
-		bool newScheduledTransaction(int transaction_type, Security *security, QWidget *parent, Account *account = NULL);
+		bool newScheduledTransaction(int transaction_type, Security *security = NULL, bool select_security = false);
+		bool newScheduledTransaction(int transaction_type, Security *security, bool select_security, QWidget *parent, Account *account = NULL);
 		bool newSplitTransaction(QWidget *parent, AssetsAccount *account = NULL);
 		bool editSplitTransaction(SplitTransaction *split);
 		bool editSplitTransaction(SplitTransaction *split, QWidget *parent);
@@ -156,6 +163,7 @@ class Eqonomize : public KMainWindow {
 		KAction *ActionSave, *ActionFileReload, *ActionSaveView, *ActionPrintView;
 		KAction *ActionOverTimeReport, *ActionCategoriesComparisonReport, *ActionOverTimeChart, *ActionCategoriesComparisonChart;
 		KAction *ActionImportCSV, *ActionImportQIF, *ActionExportQIF;
+		KSelectAction *ActionSelectInitialPeriod;
 		KToggleAction *ActionExtraProperties;
 		KRecentFilesAction *ActionOpenRecent;
 
@@ -187,7 +195,7 @@ class Eqonomize : public KMainWindow {
 		KJanusWidget *tabs;
 		QTabWidget *accountsTabs;
 		QCheckBox *budgetButton;
-		ValueSpinBox *budgetEdit;
+		EqonomizeValueEdit *budgetEdit;
 		EqonomizeMonthSelector *budgetMonthEdit;
 		QLabel *prevMonthBudgetLabel;
 		QWidget *accounts_page, *expenses_page, *incomes_page, *transfers_page, *securities_page, *schedule_page;
@@ -233,7 +241,7 @@ class Eqonomize : public KMainWindow {
 		void onAutoSaveTimeout();
 
 		void useExtraProperties(bool);
-
+	
 		void importCSV();
 		void importQIF();
 		void exportQIF();
@@ -264,6 +272,7 @@ class Eqonomize : public KMainWindow {
 		void editSecurityTransactions();
 		void securitiesSelectionChanged();
 		void securitiesExecuted(QListViewItem*);
+		void securitiesExecuted(QListViewItem*, const QPoint&, int);
 		void popupSecuritiesMenu(KListView*, QListViewItem*, const QPoint&);
 		void updateSecurities();
 		
@@ -359,6 +368,7 @@ class Eqonomize : public KMainWindow {
 		void scheduledTransactionAdded(ScheduledTransaction*);
 		void scheduledTransactionModified(ScheduledTransaction*, ScheduledTransaction*);
 		void scheduledTransactionRemoved(ScheduledTransaction*);
+		void scheduledTransactionRemoved(ScheduledTransaction*, ScheduledTransaction*);
 
 		void splitTransactionAdded(SplitTransaction*);
 		void splitTransactionRemoved(SplitTransaction*);
@@ -410,7 +420,7 @@ class EditAssetsAccountDialog : public KDialogBase {
 	protected:
 
 		KLineEdit *nameEdit;
-		KDoubleSpinBox *valueEdit;
+		EqonomizeValueEdit *valueEdit;
 		KTextEdit *descriptionEdit;
 		KComboBox *typeCombo;
 		QCheckBox *budgetButton;
@@ -439,7 +449,7 @@ class EditExpensesAccountDialog : public KDialogBase {
 	protected:
 
 		KLineEdit *nameEdit;
-		KDoubleSpinBox *budgetEdit;
+		EqonomizeValueEdit *budgetEdit;
 		KTextEdit *descriptionEdit;
 		QCheckBox *budgetButton;
 		Budget *budget;
@@ -466,7 +476,7 @@ class EditIncomesAccountDialog : public KDialogBase {
 	protected:
 
 		KLineEdit *nameEdit;
-		KDoubleSpinBox *budgetEdit;
+		EqonomizeValueEdit *budgetEdit;
 		KTextEdit *descriptionEdit;
 		QCheckBox *budgetButton;
 		Budget *budget;
@@ -494,7 +504,7 @@ class EditSecurityDialog : public KDialogBase {
 
 		KLineEdit *nameEdit;
 		KTextEdit *descriptionEdit;
-		KDoubleSpinBox *sharesEdit, *quotationEdit;
+		EqonomizeValueEdit *sharesEdit, *quotationEdit;
 		KDateEdit *quotationDateEdit;
 		KComboBox *typeCombo, *accountCombo;
 		QSpinBox *decimalsEdit;
@@ -524,7 +534,7 @@ class EditQuotationsDialog : public KDialogBase {
 
 		QLabel *titleLabel;
 		KListView *quotationsView;
-		KDoubleSpinBox *quotationEdit;
+		EqonomizeValueEdit *quotationEdit;
 		KDateEdit *dateEdit;
 		QPushButton *changeButton, *addButton, *deleteButton;
 
@@ -551,7 +561,7 @@ class RefundDialog : public KDialogBase {
 	protected:
 
 		Transaction *transaction;
-		KDoubleSpinBox *valueEdit, *quantityEdit;
+		EqonomizeValueEdit *valueEdit, *quantityEdit;
 		KDateEdit *dateEdit;
 		KComboBox *accountCombo;
 		KLineEdit *commentsEdit;
@@ -575,14 +585,17 @@ class EditReinvestedDividendDialog : public KDialogBase {
 
 	protected:
 
-		Security *security;
-		KDoubleSpinBox *sharesEdit;
+		Budget *budget;
+		KComboBox *securityCombo;
+		EqonomizeValueEdit *sharesEdit;
 		KDateEdit *dateEdit;
 
 	public:
 
-		EditReinvestedDividendDialog(Security *sec, QWidget *parent);
+		EditReinvestedDividendDialog(Budget *budg, Security *sec, bool select_security, QWidget *parent);
 
+		Security *selectedSecurity();
+		void securityChanged();
 		void setDividend(ReinvestedDividend *rediv);
 		bool modifyDividend(ReinvestedDividend *rediv);
 		ReinvestedDividend *createDividend();
@@ -600,14 +613,14 @@ class EditSecurityTradeDialog : public KDialogBase {
 
 	protected:
 
-		Security *security;
-		KComboBox *toSecurityCombo;
-		KDoubleSpinBox *valueEdit, *fromSharesEdit, *toSharesEdit;
+		Budget *budget;
+		KComboBox *fromSecurityCombo, *toSecurityCombo;
+		EqonomizeValueEdit *valueEdit, *fromSharesEdit, *toSharesEdit;
 		KDateEdit *dateEdit;
 
 	public:
 
-		EditSecurityTradeDialog(Security *sec, QWidget *parent);
+		EditSecurityTradeDialog(Budget *budg, Security *sec, QWidget *parent);
 
 		void setSecurityTrade(SecurityTrade *ts);
 		SecurityTrade *createSecurityTrade();
@@ -618,7 +631,10 @@ class EditSecurityTradeDialog : public KDialogBase {
 		
 		void slotOk();
 		void maxShares();
-		void toSecurityChanged(int);
+		Security *selectedFromSecurity();
+		Security *selectedToSecurity();
+		void fromSecurityChanged();
+		void toSecurityChanged();
 
 };
 
