@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson                                 *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
  *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,6 +25,7 @@
 #include "importcsvdialog.h"
 #include "budget.h"
 #include "kdateedit.h"
+#include "eqonomizevalueedit.h"
 
 #include <klocale.h>
 #include <kglobal.h>
@@ -129,12 +130,7 @@ ImportCSVDialog::ImportCSVDialog(Budget *budg, QWidget *parent) : KWizard(parent
 	valueCostButton = new QRadioButton(i18n("Value"), page3);
 	costGroup->insert(valueCostButton);
 	layout3->addWidget(valueCostButton, 1, 3);
-	valueCostEdit = new KDoubleSpinBox(0.0, INT_MAX / pow(10, KGlobal::locale()->fracDigits()) - 1.0, 1.0, 0.0, KGlobal::locale()->fracDigits(), page3);
-	if(KGlobal::locale()->positivePrefixCurrencySymbol() && KGlobal::locale()->negativePrefixCurrencySymbol()) {
-		valueCostEdit->setPrefix(KGlobal::locale()->currencySymbol() + " ");
-	} else {
-		valueCostEdit->setSuffix(QString(" ") + KGlobal::locale()->currencySymbol());
-	}
+	valueCostEdit = new EqonomizeValueEdit(false, page3);
 	valueCostEdit->setEnabled(false);
 	layout3->addWidget(valueCostEdit, 1, 4);
 	costLabel->hide();
@@ -156,12 +152,7 @@ ImportCSVDialog::ImportCSVDialog(Budget *budg, QWidget *parent) : KWizard(parent
 	valueValueButton = new QRadioButton(i18n("Value"), page3);
 	valueGroup->insert(valueValueButton);
 	layout3->addWidget(valueValueButton, 2, 3);
-	valueValueEdit = new KDoubleSpinBox(0.0, INT_MAX / pow(10, KGlobal::locale()->fracDigits()) - 1.0, 1.0, 0.0, KGlobal::locale()->fracDigits(), page3);
-	if(KGlobal::locale()->positivePrefixCurrencySymbol() && KGlobal::locale()->negativePrefixCurrencySymbol()) {
-		valueValueEdit->setPrefix(KGlobal::locale()->currencySymbol() + " ");
-	} else {
-		valueValueEdit->setSuffix(QString(" ") + KGlobal::locale()->currencySymbol());
-	}
+	valueValueEdit = new EqonomizeValueEdit(false, page3);
 	valueValueEdit->setEnabled(false);
 	layout3->addWidget(valueValueEdit, 2, 4);
 
