@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson                                 *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
  *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,7 +29,7 @@ class QLabel;
 class QRadioButton;
 class QSpinBox;
 class KDateEdit;
-class KDoubleSpinBox;
+class EqonomizeValueEdit;
 class KLineEdit;
 class KComboBox;
 class KURLRequester;
@@ -59,12 +59,12 @@ class ImportCSVDialog : public KWizard {
 		QLabel *valueLabel;
 		QRadioButton *columnValueButton, *valueValueButton;
 		QSpinBox *columnValueEdit;
-		KDoubleSpinBox *valueValueEdit;
+		EqonomizeValueEdit *valueValueEdit;
 
 		QLabel *costLabel;
 		QRadioButton *columnCostButton, *valueCostButton;
 		QSpinBox *columnCostEdit;
-		KDoubleSpinBox *valueCostEdit;
+		EqonomizeValueEdit *valueCostEdit;
 
 		QRadioButton *columnDateButton, *valueDateButton;
 		QSpinBox *columnDateEdit;
