@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -344,7 +344,7 @@ void LedgerDialog::joinTransactions() {
 	LedgerListViewItem *i = (LedgerListViewItem*) selection.first();
 	while(i) {
 		Transaction *trans = i->transaction();
-		if(trans && !i->splitTransaction() && trans->type() != TRANSACTION_TYPE_SECURITY_BUY && trans->type() != TRANSACTION_TYPE_SECURITY_SELL && (trans->type() != TRANSACTION_TYPE_INCOME || !((Income*) trans)->security())) {
+		if(trans && !i->splitTransaction()) {
 			if(!split) {
 				split = new SplitTransaction(budget, i->transaction()->date(), account);
 			}
@@ -404,22 +404,19 @@ void LedgerDialog::transactionSelectionChanged() {
 		if(b_join && trans->parentSplit()) {
 			b_join = false;
 		}
-		if(b_join && trans->type() == TRANSACTION_TYPE_SECURITY_BUY || trans->type() == TRANSACTION_TYPE_SECURITY_SELL || (trans->type() == TRANSACTION_TYPE_INCOME && ((Income*) trans)->security())) {
-			b_join = false;
-		}
 		i = (LedgerListViewItem*) selection.next();
 	}	
 	joinButton->setEnabled(b_join);
 	splitUpButton->setEnabled(b_split);
 }
 void LedgerDialog::newExpense() {
-	mainWin->newScheduledTransaction(TRANSACTION_TYPE_EXPENSE, NULL, this, account);
+	mainWin->newScheduledTransaction(TRANSACTION_TYPE_EXPENSE, NULL, false, this, account);
 }
 void LedgerDialog::newIncome() {
-	mainWin->newScheduledTransaction(TRANSACTION_TYPE_INCOME, NULL, this, account);
+	mainWin->newScheduledTransaction(TRANSACTION_TYPE_INCOME, NULL, false, this, account);
 }
 void LedgerDialog::newTransfer() {
-	mainWin->newScheduledTransaction(TRANSACTION_TYPE_TRANSFER, NULL, this, account);
+	mainWin->newScheduledTransaction(TRANSACTION_TYPE_TRANSFER, NULL, false, this, account);
 }
 void LedgerDialog::newSplit() {
 	mainWin->newSplitTransaction(this, account);
@@ -431,7 +428,7 @@ void LedgerDialog::remove() {
 	QPtrList<QListViewItem> selection = transactionsView->selectedItems();
 #endif
 	if(selection.count() > 1) {
-		if(!KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to delete all (%1) selected transactions?").arg(selection.count()))) {
+		if(KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to delete all (%1) selected transactions?").arg(selection.count())) == KMessageBox::Cancel) {
 			return;
 		}
 	}
@@ -605,20 +602,38 @@ void LedgerDialog::updateTransactions() {
 	double balance = account->initialBalance();
 	if(balance != 0.0) new LedgerListViewItem(NULL, NULL, transactionsView, "-", "-", "Initial balance", "-", QString::null, QString::null, KGlobal::locale()->formatMoney(balance));
 	Transaction *trans = budget->transactions.first();
-	SplitTransaction *split = NULL;
+	QValueVector<SplitTransaction*> splits;
 	while(trans) {
-		if((!split || split != trans->parentSplit()) && (trans->fromAccount() == account || trans->toAccount() == account)) {
-			split = trans->parentSplit();
-			if(split && split->account() != account) split = NULL;
-			bool deposit = split || (trans->toAccount() == account);
+		SplitTransaction *split_this = trans->parentSplit();
+		bool skip = false;
+		if(!splits.isEmpty() && split_this) {
+			if(splits[splits.size() - 1]->date() != split_this->date()) {
+				splits.clear();
+			} else if(split_this) {
+				for(QValueVector<SplitTransaction*>::size_type i = 0; i < splits.size(); i++) {
+					if(split_this == splits[i]) {
+						skip = true;
+						break;
+					}
+				}
+			}
+		}
+		if(!skip && (trans->fromAccount() == account || trans->toAccount() == account)) {
+			if(split_this && split_this->account() != account) split_this = NULL;
+			if(split_this) splits.push_back(split_this);
+			bool deposit = split_this || (trans->toAccount() == account);
 			double value = 0.0;
-			if(split) value = split->value();
+			if(split_this) value = split_this->value();
 			else value = trans->value();
 			if(deposit) balance += value;
 			else balance -= value;
-			if(split) {
-				LedgerListViewItem *i = new LedgerListViewItem(trans, split, transactionsView, KGlobal::locale()->formatDate(split->date(), true), i18n("Split Transaction"), split->description(), (value >= 0.0) ? KGlobal::locale()->formatMoney(value) : QString::null, QString::null, (value < 0.0) ? KGlobal::locale()->formatMoney(-value) : QString::null, KGlobal::locale()->formatMoney(balance));
-				if(split == selected_split) {
+			if(!split_this && value < 0.0) {
+				deposit = !deposit;
+				value = -value;
+			}
+			if(split_this) {
+				LedgerListViewItem *i = new LedgerListViewItem(trans, split_this, transactionsView, KGlobal::locale()->formatDate(split_this->date(), true), i18n("Split Transaction"), split_this->description(), (value >= 0.0) ? KGlobal::locale()->formatMoney(value) : QString::null, QString::null, (value < 0.0) ? KGlobal::locale()->formatMoney(-value) : QString::null, KGlobal::locale()->formatMoney(balance));
+				if(split_this == selected_split) {
 					transactionsView->setSelected(i, true);
 				}
 			} else {
