@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson                                 *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
  *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -989,16 +989,20 @@ void importQIF(QTextStream &fstream, bool test, qif_info &qi, Budget *budget) {
 					if(type >= 9) {
 						int i = line.find('/');
 						if(i >= 0) line.truncate(i);
-						category = line;
+						category = line;						
 						i = line.find(':');
 						if(i >= 0) {
+							bool is_transfer = line.length() >= 2 && line[0] == '[' && line.endsWith("]");
+							if(is_transfer) line.truncate(line.length() - 1);
 							if(qi.subcategory_as_category) {
 								i = line.findRev(':');
 								category.remove(0, i + 1);
 								category = category.stripWhiteSpace();
+								if(is_transfer) category += "]";
 							} else {
 								category.truncate(i);
 								category = category.stripWhiteSpace();
+								if(is_transfer) category += "]";
 								subcategory = line;
 								subcategory.remove(0, i + 1);
 								subcategory = subcategory.stripWhiteSpace();
@@ -1058,13 +1062,17 @@ void importQIF(QTextStream &fstream, bool test, qif_info &qi, Budget *budget) {
 						current_split->category = line;
 						i = line.find(':');
 						if(i >= 0) {
+							bool is_transfer = line.length() >= 2 && line[0] == '[' && line.endsWith("]");
+							if(is_transfer) line.truncate(line.length() - 1);
 							if(qi.subcategory_as_category) {
 								i = line.findRev(':');
 								current_split->category.remove(0, i + 1);
 								current_split->category = current_split->category.stripWhiteSpace();
+								if(is_transfer) current_split->category += "]";
 							} else {
 								current_split->category.truncate(i);
 								current_split->category = current_split->category.stripWhiteSpace();
+								if(is_transfer) current_split->category += "]";
 								current_split->subcategory = line;
 								current_split->subcategory.remove(0, i + 1);
 								current_split->subcategory = current_split->subcategory.stripWhiteSpace();
