@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -203,7 +203,7 @@ void Income::save(QDomElement *e) const {
 
 Transfer::Transfer(Budget *parent_budget, double initial_amount, QDate initial_date, AssetsAccount *initial_from, AssetsAccount *initial_to, QString initial_description, QString initial_comment) : Transaction(parent_budget, initial_amount < 0.0 ? -initial_amount : initial_amount, initial_date, initial_amount < 0.0 ? initial_to : initial_from, initial_amount < 0.0 ? initial_from : initial_to, initial_description, initial_comment) {}
 Transfer::Transfer(Budget *parent_budget, QDomElement *e, bool *valid, bool internal_is_balancing) : Transaction(parent_budget, e, valid) {
-	if(internal_is_balancing) {setAmount(e->attribute("amount").toDouble()); return;}
+	if(internal_is_balancing) {return;}
 	int id_from = e->attribute("from").toInt();
 	int id_to = e->attribute("to").toInt();
 	if(parent_budget->assetsAccounts_id.contains(id_from) && parent_budget->assetsAccounts_id.contains(id_to)) {
@@ -254,11 +254,14 @@ Balancing::Balancing(Budget *parent_budget, double initial_amount, QDate initial
 }
 Balancing::Balancing(Budget *parent_budget, QDomElement *e, bool *valid) : Transfer(parent_budget, e, valid, true) {
 	if(s_description.isEmpty()) setDescription(i18n("Account balancing"));
-	if(amount() < 0.0) {
-		setAmount(-amount());
+	d_value = e->attribute("amount").toDouble();
+	if(d_value < 0.0) {
+		d_value = -d_value;
 		setToAccount(parent_budget->balancingAccount);
+		setFromAccount(NULL);
 	} else {
 		setFromAccount(parent_budget->balancingAccount);
+		setToAccount(NULL);
 	}
 	int id_account = e->attribute("account").toInt();
 	if(parent_budget->assetsAccounts_id.contains(id_account)) {
@@ -490,7 +493,10 @@ Transaction *ScheduledTransaction::realize(const QDate &date) {
 	if(o_rec && !o_rec->removeOccurrence(date)) return NULL;
 	if(!o_rec && date != o_trans->date()) return NULL;
 	Transaction *trans = o_trans->copy();
-	if(o_rec) o_trans->setDate(o_rec->startDate());
+	if(o_rec) {
+		o_trans->setDate(o_rec->startDate());
+		o_budget->scheduledTransactionDateModified(this);
+	}
 	trans->setDate(date);
 	return trans;
 }
@@ -592,6 +598,7 @@ void ScheduledTransaction::addException(const QDate &exceptiondate) {
 	if(o_trans && exceptiondate == o_rec->startDate()) {
 		o_rec->addException(exceptiondate);
 		o_trans->setDate(o_rec->startDate());
+		o_budget->scheduledTransactionDateModified(this);
 	} else {
 		o_rec->addException(exceptiondate);
 	}
@@ -617,13 +624,26 @@ SplitTransaction::SplitTransaction(Budget *parent_budget, QDomElement *e, bool *
 					if(type == "expense") {
 						e2.setAttribute("from", id);
 						trans = new Expense(parent_budget, &e2, &valid2);
-					} else if(type == "income") {
+					} else if(type == "income") {						
 						e2.setAttribute("to", id);
 						trans = new Income(parent_budget, &e2, &valid2);
+					} else if(type == "dividend") {
+						e2.setAttribute("to", id);
+						trans = new Income(parent_budget, &e2, &valid2);
+						if(!((Income*) trans)->security()) valid2 = false;
+					} else if(type == "balancing") {
+						e2.setAttribute("account", id);
+						trans = new Balancing(parent_budget, &e2, &valid2);
 					} else if(type == "transfer") {
 						if(e2.hasAttribute("to")) e2.setAttribute("from", id);
 						else e2.setAttribute("to", id);
 						trans = new Transfer(parent_budget, &e2, &valid2);
+					} else if(type == "security_buy") {
+						e2.setAttribute("account", id);
+						trans = new SecurityBuy(parent_budget, &e2, &valid2);
+					} else if(type == "security_sell") {
+						e2.setAttribute("account", id);
+						trans = new SecuritySell(parent_budget, &e2, &valid2);
 					}
 					if(!valid2) {
 						delete trans;
@@ -758,17 +778,26 @@ void SplitTransaction::save(QDomElement *e) const {
 		trans->save(&e2);
 		e2.removeAttribute("date");
 		switch(trans->type()) {
-			case TRANSACTION_TYPE_TRANSFER: {
-				e2.setAttribute("type", "transfer");
-				if(((Transfer*) trans)->from() == o_account) {
-					e2.removeAttribute("from");
+			case TRANSACTION_TYPE_TRANSFER: {				
+				if(trans->fromAccount() == o_budget->balancingAccount) {
+					e2.setAttribute("type", "balancing");
+					e2.removeAttribute("account");
 				} else {
-					e2.removeAttribute("to");
-				}				
+					e2.setAttribute("type", "transfer");
+					if(((Transfer*) trans)->from() == o_account) {
+						e2.removeAttribute("from");
+					} else {
+						e2.removeAttribute("to");
+					}
+				}
 				break;
 			}
 			case TRANSACTION_TYPE_INCOME: {
-				e2.setAttribute("type", "income");
+				if(((Income*) trans)->security()) {
+					e2.setAttribute("type", "dividend");
+				} else {
+					e2.setAttribute("type", "income");
+				}
 				e2.removeAttribute("to");
 				break;
 			}
@@ -777,6 +806,16 @@ void SplitTransaction::save(QDomElement *e) const {
 				e2.removeAttribute("from");
 				break;
 			}
+			case TRANSACTION_TYPE_SECURITY_BUY: {
+				e2.setAttribute("type", "security_buy");
+				e2.removeAttribute("account");
+				break;
+			}
+			case TRANSACTION_TYPE_SECURITY_SELL: {
+				e2.setAttribute("type", "security_sell");
+				e2.removeAttribute("account");
+				break;
+			}
 			default: {}
 		}	
 		e->appendChild(e2);
