@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson                                 *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
  *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -46,6 +46,12 @@ typedef enum {
 	TRANSACTION_TYPE_SECURITY_SELL
 } TransactionType;
 
+typedef enum {
+	TRANSACTION_STATUS_NONE,
+	TRANSACTION_STATUS_CLEARED,
+	TRANSACTION_STATUS_RECONCILED
+} TransactionStatus;
+
 class Transaction {
 
 	protected:
@@ -66,6 +72,8 @@ class Transaction {
 
 		SplitTransaction *o_split;
 
+		//TransactionStatus ts_status;
+
 	public:
 
 		Transaction(Budget *parent_budget, double initial_value, QDate initial_date, Account *from, Account *to, QString initial_description = emptystr, QString initial_comment = emptystr);
