@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,6 +25,7 @@
 #include "transactioneditwidget.h"
 #include "budget.h"
 #include "recurrence.h"
+#include "eqonomizevalueedit.h"
 
 #include <math.h>
 #include <kglobal.h>
@@ -68,7 +69,7 @@ extern double monthsBetweenDates(const QDate &date1, const QDate &d2);
 
 #define TEROWCOL(row, col)	row % rows, ((row / rows) * 2) + col
 
-TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *sec, SecurityValueDefineType security_value_type, Budget *budg, QWidget *parent, const char *name) : QWidget(parent, name), transtype(transaction_type), budget(budg), security(sec), b_autoedit(auto_edit), b_extra(extra_parameters) {
+TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *sec, SecurityValueDefineType security_value_type, bool select_security, Budget *budg, QWidget *parent, const char *name) : QWidget(parent, name), transtype(transaction_type), budget(budg), security(sec), b_autoedit(auto_edit), b_extra(extra_parameters) {
 	value_set = false; shares_set = false; sharevalue_set = false;
 	b_sec = (transtype == TRANSACTION_TYPE_SECURITY_BUY || transtype == TRANSACTION_TYPE_SECURITY_SELL);
 	QVBoxLayout *editVLayout = new QVBoxLayout(this, 0, 6);
@@ -76,7 +77,7 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 	if(auto_edit) cols = 2;
 	int rows = 6;
 	if(b_sec && security_value_type == SECURITY_ALL_VALUES) rows = 7;
-	else if(b_extra && !security && (transtype == TRANSACTION_TYPE_EXPENSE || transtype == TRANSACTION_TYPE_INCOME)) rows = 8;
+	else if(b_extra && !security && !select_security && (transtype == TRANSACTION_TYPE_EXPENSE || transtype == TRANSACTION_TYPE_INCOME)) rows = 8;
 	if(rows % cols > 0) rows += rows / cols + 1;
 	else rows = rows / cols;	
 	QGridLayout *editLayout = new QGridLayout(editVLayout, rows, cols * 2);
@@ -89,35 +90,46 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 	quantityEdit = NULL;
 	toCombo = NULL;
 	fromCombo = NULL;
+	securityCombo = NULL;
 	int i = 0;
 	if(b_sec) {
-		int decimals = 4;
-		decimals = security->decimals();
+		int decimals = 4;		
 		editLayout->addWidget(new QLabel(i18n("Security:"), this), TEROWCOL(i, 0));
-		editLayout->addWidget(new QLabel(security->name(), this), TEROWCOL(i, 1));
+		if(select_security) {
+			securityCombo = new KComboBox(this);
+			securityCombo->setEditable(false);
+			Security *c_sec = budget->securities.first();
+			int i2 = 0;
+			while(c_sec) {
+				securityCombo->insertItem(c_sec->name());
+				if(c_sec == security) securityCombo->setCurrentItem(i2);
+				c_sec = budget->securities.next();
+				i2++;
+			}
+			editLayout->addWidget(securityCombo, TEROWCOL(i, 1));
+			if(!security) security = selectedSecurity();
+		} else {
+			editLayout->addWidget(new QLabel(security->name(), this), TEROWCOL(i, 1));
+		}		
+		if(security) decimals = security->decimals();
 		i++;
 		if(security_value_type != SECURITY_SHARES_AND_QUOTATION) {
 			if(transtype == TRANSACTION_TYPE_SECURITY_BUY) editLayout->addWidget(new QLabel(i18n("Cost:"), this), TEROWCOL(i, 0));
 			else editLayout->addWidget(new QLabel(i18n("Income:"), this), TEROWCOL(i, 0));
-			valueEdit = new ValueSpinBox(0.0, INT_MAX / pow(10, KGlobal::locale()->fracDigits()) - 1.0, 1.0, 0.0, KGlobal::locale()->fracDigits(), this);
-			if(KGlobal::locale()->positivePrefixCurrencySymbol() && KGlobal::locale()->negativePrefixCurrencySymbol()) {
-				valueEdit->setPrefix(KGlobal::locale()->currencySymbol() + " ");
-			} else {
-				valueEdit->setSuffix(QString(" ") + KGlobal::locale()->currencySymbol());
-			}
+			valueEdit = new EqonomizeValueEdit(false, this);
 			editLayout->addWidget(valueEdit, TEROWCOL(i, 1));
 			i++;
 		}
 		if(security_value_type != SECURITY_VALUE_AND_QUOTATION) {
 			if(transtype == TRANSACTION_TYPE_SECURITY_BUY) {
 				editLayout->addWidget(new QLabel(i18n("Shares bought:"), this), TEROWCOL(i, 0));
-				sharesEdit = new ValueSpinBox(0.0, INT_MAX / pow(10.0, decimals) - 1.0, 1.0, 0.0, decimals, this);
+				sharesEdit = new EqonomizeValueEdit(0.0, decimals, false, false, this);
 				editLayout->addWidget(sharesEdit, TEROWCOL(i, 1));
 				i++;
 			} else {
 				editLayout->addWidget(new QLabel(i18n("Shares sold:"), this), TEROWCOL(i, 0));
 				QHBoxLayout *sharesLayout = new QHBoxLayout(0);
-				sharesEdit = new ValueSpinBox(0.0, INT_MAX / pow(10.0, decimals) - 1.0, 1.0, 0.0, decimals, this);
+				sharesEdit = new EqonomizeValueEdit(0.0, decimals, false, false, this);
 				sharesEdit->setSizePolicy(QSizePolicy::Expanding, sharesEdit->sizePolicy().verData());
 				sharesLayout->addWidget(sharesEdit);
 				maxSharesButton = new QPushButton(i18n("All"), this);
@@ -129,12 +141,7 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 		}
 		if(security_value_type != SECURITY_VALUE_AND_SHARES) {
 			editLayout->addWidget(new QLabel(i18n("Price per share:"), this), TEROWCOL(i, 0));
-			quotationEdit = new ValueSpinBox(0.0, INT_MAX / pow(10, KGlobal::locale()->fracDigits()) - 1.0, 1.0, 0.0, KGlobal::locale()->fracDigits(), this);
-			if(KGlobal::locale()->positivePrefixCurrencySymbol() && KGlobal::locale()->negativePrefixCurrencySymbol()) {
-				quotationEdit->setPrefix(KGlobal::locale()->currencySymbol() + " ");
-			} else {
-				quotationEdit->setSuffix(QString(" ") + KGlobal::locale()->currencySymbol());
-			}
+			quotationEdit = new EqonomizeValueEdit(false, this);			
 			editLayout->addWidget(quotationEdit, TEROWCOL(i, 1));
 			i++;
 		}
@@ -145,37 +152,45 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 		}
 		i++;
 	} else {
-		if(transtype == TRANSACTION_TYPE_INCOME && security) {
+		if(transtype == TRANSACTION_TYPE_INCOME && (security || select_security)) {
 			editLayout->addWidget(new QLabel(i18n("Security:"), this), TEROWCOL(i, 0));
-			editLayout->addWidget(new QLabel(security->name(), this), TEROWCOL(i, 1));
+			if(select_security) {
+				securityCombo = new KComboBox(this);
+				securityCombo->setEditable(false);
+				Security *c_sec = budget->securities.first();
+				int i2 = 0;
+				while(c_sec) {
+					securityCombo->insertItem(c_sec->name());
+					if(c_sec == security) securityCombo->setCurrentItem(i2);
+					c_sec = budget->securities.next();
+					i2++;
+				}
+				editLayout->addWidget(securityCombo, TEROWCOL(i, 1));
+				if(!security) security = selectedSecurity();
+			} else {
+				editLayout->addWidget(new QLabel(security->name(), this), TEROWCOL(i, 1));
+			}
 		} else {
 			editLayout->addWidget(new QLabel(i18n("Description:"), this), TEROWCOL(i, 0));
 			descriptionEdit = new KLineEdit(this);
 			descriptionEdit->setCompletionMode(KGlobalSettings::CompletionPopup);
-		}
-		editLayout->addWidget(descriptionEdit, TEROWCOL(i, 1));
+			editLayout->addWidget(descriptionEdit, TEROWCOL(i, 1));
+		}		
 		i++;
 		if(transtype == TRANSACTION_TYPE_TRANSFER) {
 			editLayout->addWidget(new QLabel(i18n("Amount:"), this), TEROWCOL(i, 0));
-			//valueEdit = new ValueSpinBox(0.0, INT_MAX / pow(10, KGlobal::locale()->fracDigits()) - 1.0, 1.0, 0.0, KGlobal::locale()->fracDigits(), this);
 		} else if(transtype == TRANSACTION_TYPE_INCOME) {
 			editLayout->addWidget(new QLabel(i18n("Income:"), this), TEROWCOL(i, 0));
-			//valueEdit = new ValueSpinBox(INT_MIN / pow(10, KGlobal::locale()->fracDigits()) + 1.0, INT_MAX / pow(10, KGlobal::locale()->fracDigits()) - 1.0, 1.0, 0.0, KGlobal::locale()->fracDigits(), this);
 		} else {
 			editLayout->addWidget(new QLabel(i18n("Cost:"), this), TEROWCOL(i, 0));
 			
-		 }
-		 valueEdit = new ValueSpinBox(INT_MIN / pow(10, KGlobal::locale()->fracDigits()) + 1.0, INT_MAX / pow(10, KGlobal::locale()->fracDigits()) - 1.0, 1.0, 0.0, KGlobal::locale()->fracDigits(), this);
-		if(KGlobal::locale()->positivePrefixCurrencySymbol() && KGlobal::locale()->negativePrefixCurrencySymbol()) {
-			valueEdit->setPrefix(KGlobal::locale()->currencySymbol() + " ");
-		} else {
-			valueEdit->setSuffix(QString(" ") + KGlobal::locale()->currencySymbol());
 		}
+		valueEdit = new EqonomizeValueEdit(true, this);
 		editLayout->addWidget(valueEdit, TEROWCOL(i, 1));
 		i++;
-		if(b_extra && !security && (transtype == TRANSACTION_TYPE_EXPENSE || transtype == TRANSACTION_TYPE_INCOME)) {
+		if(b_extra && !select_security && !security && (transtype == TRANSACTION_TYPE_EXPENSE || transtype == TRANSACTION_TYPE_INCOME)) {
 			editLayout->addWidget(new QLabel(i18n("Quantity:"), this), TEROWCOL(i, 0));
-			quantityEdit = new ValueSpinBox(INT_MIN / 100 + 1.0, INT_MAX / 100 - 1.0, 1.0, 1.0, 2, this);
+			quantityEdit = new EqonomizeValueEdit(INT_MIN / 100 + 1.0, INT_MAX / 100 - 1.0, 1.0, 1.0, 2, false, this);
 			editLayout->addWidget(quantityEdit, TEROWCOL(i, 1));
 			i++;
 		}
@@ -217,7 +232,7 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 				editLayout->addWidget(toCombo, TEROWCOL(i, 1));
 				i++;
 			}
-			if(b_extra && !security) {
+			if(b_extra && !select_security && !security) {
 				editLayout->addWidget(new QLabel(i18n("Payer:"), this), TEROWCOL(i, 0));
 				payeeEdit = new KLineEdit(this);
 				payeeEdit->setCompletionMode(KGlobalSettings::CompletionPopup);
@@ -350,13 +365,22 @@ TransactionEditWidget::TransactionEditWidget(bool auto_edit, bool extra_paramete
 		}		
 	}
 	if(b_autoedit && dateEdit) connect(dateEdit, SIGNAL(returnPressed()), this, SIGNAL(addmodify()));
+	if(payeeEdit) connect(payeeEdit, SIGNAL(returnPressed()), commentsEdit, SLOT(setFocus()));
 	if(b_autoedit) connect(commentsEdit, SIGNAL(returnPressed()), this, SIGNAL(addmodify()));
+	if(securityCombo) connect(securityCombo, SIGNAL(activated(int)), this, SLOT(securityChanged()));
 }
 void TransactionEditWidget::currentDateChanged(const QDate &olddate, const QDate &newdate) {
 	if(dateEdit && olddate == dateEdit->date() && valueEdit && valueEdit->value() == 0.0 && descriptionEdit && descriptionEdit->text().isEmpty()) {
 		dateEdit->setDate(newdate);
 	}
 }
+void TransactionEditWidget::securityChanged() {
+	security = selectedSecurity();
+	if(security) {
+		if(sharesEdit) sharesEdit->setPrecision(security->decimals());
+		if(sharesEdit && security && shares_date.isValid()) sharesEdit->setMaxValue(security->shares(shares_date));
+	}
+}
 void TransactionEditWidget::valueChanged(double value) {
 	if(!quotationEdit || !sharesEdit || !valueEdit) return;
 	value_set = true;
@@ -399,8 +423,12 @@ void TransactionEditWidget::quotationChanged(double value) {
 void TransactionEditWidget::setMaxShares(double max) {
 	if(sharesEdit) sharesEdit->setMaxValue(max);
 }
+void TransactionEditWidget::setMaxSharesDate(QDate quotation_date) {
+	shares_date = quotation_date;
+	if(sharesEdit && security && shares_date.isValid()) sharesEdit->setMaxValue(security->shares(shares_date));
+}
 void TransactionEditWidget::maxShares() {
-	if(security && sharesEdit) sharesEdit->setValue(security->shares());
+	if(selectedSecurity() && sharesEdit) sharesEdit->setValue(selectedSecurity()->shares(dateEdit->date()));
 }
 QWidget *TransactionEditWidget::bottomWidget() {
 	return bottom_widget;
@@ -441,7 +469,10 @@ void TransactionEditWidget::setDefaultValue() {
 					}
 				}
 			}
-			if(quantityEdit) quantityEdit->setValue(trans->quantity());
+			if(quantityEdit) {
+				if(trans->quantity() <= 0.0) quantityEdit->setValue(1.0);
+				else quantityEdit->setValue(trans->quantity());
+			}
 			if(payeeEdit && trans->type() == TRANSACTION_TYPE_EXPENSE) payeeEdit->setText(((Expense*) trans)->payee());
 			if(payeeEdit && trans->type() == TRANSACTION_TYPE_INCOME) payeeEdit->setText(((Income*) trans)->payer());
 		}
@@ -663,9 +694,13 @@ bool TransactionEditWidget::checkAccounts() {
 			break;
 		}
 	}
+	if(securityCombo && securityCombo->count() == 0) {
+		KMessageBox::error(this, i18n("No security available."));
+		return false;
+	}
 	return true;
 }
-bool TransactionEditWidget::validValues() {
+bool TransactionEditWidget::validValues(bool) {
 	if(dateEdit && !dateEdit->date().isValid()) {
 		KMessageBox::error(this, i18n("Invalid date."));
 		dateEdit->setFocus();
@@ -706,6 +741,11 @@ bool TransactionEditWidget::validValues() {
 				KMessageBox::error(this, i18n("Zero price per share not allowed."));
 				return false;
 			}
+			/*if(ask_questions && sharesEdit && selectedSecurity() && sharesEdit->value() > selectedSecurity()->shares(dateEdit->date())) {
+				if(KMessageBox::warningContinueCancel(this, i18n("Number of sold shares are greater than available shares at selected date. Do you want to create the transaction nevertheless?")) == KMessageBox::Cancel) {
+					return false;
+				}
+			}*/
 			break;
 		}
 		default: {			
@@ -755,6 +795,20 @@ bool TransactionEditWidget::modifyTransaction(Transaction *trans) {
 	if(payeeEdit && trans->type() == TRANSACTION_TYPE_INCOME) ((Income*) trans)->setPayer(payeeEdit->text());
 	return true;
 }
+Security *TransactionEditWidget::selectedSecurity() {
+	if(securityCombo) {
+		int i = securityCombo->currentItem();
+		if(i >= 0) {
+			Security *c_sec = budget->securities.first();
+			while(i > 0 && c_sec) {
+				c_sec = budget->securities.next();
+				i--;
+			}
+			return c_sec;
+		}
+	}
+	return security;
+}
 Transaction *TransactionEditWidget::createTransaction() {
 	if(!validValues()) return NULL;
 	Transaction *trans;
@@ -763,12 +817,12 @@ Transaction *TransactionEditWidget::createTransaction() {
 		trans = transfer;
 	} else if(transtype == TRANSACTION_TYPE_INCOME) {
 		Income *income = new Income(budget, valueEdit->value(), dateEdit ? dateEdit->date() : QDate(), fromCombo ? (IncomesAccount*) froms[fromCombo->currentItem()] : NULL, toCombo ? (AssetsAccount*) tos[toCombo->currentItem()] : NULL, descriptionEdit ? descriptionEdit->text() : QString::null, commentsEdit->text());
-		if(security) income->setSecurity(security);
+		if(selectedSecurity()) income->setSecurity(selectedSecurity());
 		if(quantityEdit) income->setQuantity(quantityEdit->value());
 		if(payeeEdit) income->setPayer(payeeEdit->text());
 		trans = income;
 	} else if(transtype == TRANSACTION_TYPE_SECURITY_BUY) {		
-		if(!security) return NULL;
+		if(!selectedSecurity()) return NULL;
 		double shares = 0.0, value = 0.0, share_value = 0.0;
 		if(valueEdit) value = valueEdit->value();
 		if(sharesEdit) shares = sharesEdit->value();
@@ -776,10 +830,10 @@ Transaction *TransactionEditWidget::createTransaction() {
 		if(!quotationEdit) share_value = value / shares;
 		else if(!sharesEdit) shares = value / share_value;
 		else if(!valueEdit) value = shares * share_value;
-		SecurityBuy *secbuy = new SecurityBuy(security, value, shares, share_value, dateEdit ? dateEdit->date() : QDate(), fromCombo ? froms[fromCombo->currentItem()] : NULL, commentsEdit->text());
+		SecurityBuy *secbuy = new SecurityBuy(selectedSecurity(), value, shares, share_value, dateEdit ? dateEdit->date() : QDate(), fromCombo ? froms[fromCombo->currentItem()] : NULL, commentsEdit->text());
 		trans = secbuy;
 	} else if(transtype == TRANSACTION_TYPE_SECURITY_SELL) {
-		if(!security) return NULL;
+		if(!selectedSecurity()) return NULL;
 		double shares = 0.0, value = 0.0, share_value = 0.0;
 		if(valueEdit) value = valueEdit->value();
 		if(sharesEdit) shares = sharesEdit->value();
@@ -787,7 +841,7 @@ Transaction *TransactionEditWidget::createTransaction() {
 		if(!quotationEdit) share_value = value / shares;
 		else if(!sharesEdit) shares = value / share_value;
 		else if(!valueEdit) value = shares * share_value;
-		SecuritySell *secsell = new SecuritySell(security, value, shares, share_value, dateEdit ? dateEdit->date() : QDate(), toCombo ? tos[toCombo->currentItem()] : NULL, commentsEdit->text());
+		SecuritySell *secsell = new SecuritySell(selectedSecurity(), value, shares, share_value, dateEdit ? dateEdit->date() : QDate(), toCombo ? tos[toCombo->currentItem()] : NULL, commentsEdit->text());
 		trans = secsell;
 	} else {
 		Expense *expense = new Expense(budget, valueEdit->value(), dateEdit ? dateEdit->date() : QDate(), toCombo ? (ExpensesAccount*) tos[toCombo->currentItem()] : NULL, fromCombo ? (AssetsAccount*) froms[fromCombo->currentItem()] : NULL, descriptionEdit->text(), commentsEdit->text());
@@ -939,7 +993,7 @@ void TransactionEditWidget::setTransaction(Transaction *trans) {
 			valueEdit->setValue(0.0);
 		}
 		commentsEdit->clear();
-		if(quantityEdit) quantityEdit->setValue(0.0);
+		if(quantityEdit) quantityEdit->setValue(1.0);
 		if(payeeEdit) payeeEdit->clear();
 	} else {
 		value_set = true; shares_set = true; sharevalue_set = true;
@@ -963,7 +1017,7 @@ void TransactionEditWidget::setTransaction(Transaction *trans) {
 		}
 		if(b_sec) {
 			if(transtype != trans->type()) return;
-			if(transtype == TRANSACTION_TYPE_SECURITY_SELL) setMaxShares(((SecurityTransaction*) trans)->security()->shares(QDate::currentDate()) + ((SecurityTransaction*) trans)->shares());
+			//if(transtype == TRANSACTION_TYPE_SECURITY_SELL) setMaxShares(((SecurityTransaction*) trans)->security()->shares(QDate::currentDate()) + ((SecurityTransaction*) trans)->shares());
 			if(sharesEdit) sharesEdit->setValue(((SecurityTransaction*) trans)->shares());
 			if(quotationEdit) quotationEdit->setValue(((SecurityTransaction*) trans)->shareValue());
 			if(valueEdit) valueEdit->setValue(trans->value());
@@ -998,24 +1052,11 @@ void TransactionEditWidget::setScheduledTransaction(ScheduledTransaction *strans
 	}
 }
 
-ValueSpinBox::ValueSpinBox(QWidget *parent, const char *name) : KDoubleSpinBox(parent, name) {
-	connect(editor(), SIGNAL(returnPressed()), this, SIGNAL(returnPressed()));
-}
-ValueSpinBox::ValueSpinBox(double lower, double upper, double step, double value, int precision, QWidget *parent, const char *name) : KDoubleSpinBox(lower, upper, step, value, precision, parent, name) {
-	connect(editor(), SIGNAL(returnPressed()), this, SIGNAL(returnPressed()));
-}
-QLineEdit *ValueSpinBox::lineEdit() const {
-	return editor();
-}
-void ValueSpinBox::selectAll() {
-	editor()->selectAll();
-}
-
-TransactionEditDialog::TransactionEditDialog(bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *security, SecurityValueDefineType security_value_type, Budget *budg, QWidget *parent) : KDialogBase(parent, 0, true, QString::null, KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, true){
+TransactionEditDialog::TransactionEditDialog(bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *security, SecurityValueDefineType security_value_type, bool select_security, Budget *budg, QWidget *parent) : KDialogBase(parent, 0, true, QString::null, KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, true){
 	switch(transaction_type) {
 		case TRANSACTION_TYPE_EXPENSE: {setPlainCaption(i18n("Edit Expense")); break;}
 		case TRANSACTION_TYPE_INCOME: {
-			if(security) setPlainCaption(i18n("Edit Dividend"));
+			if(security || select_security) setPlainCaption(i18n("Edit Dividend"));
 			else setPlainCaption(i18n("Edit Income"));
 			break;
 		}
@@ -1023,12 +1064,12 @@ TransactionEditDialog::TransactionEditDialog(bool extra_parameters, int transact
 		case TRANSACTION_TYPE_SECURITY_BUY: {setPlainCaption(i18n("Edit Securities Bought")); break;}
 		case TRANSACTION_TYPE_SECURITY_SELL: {setPlainCaption(i18n("Edit Securities Sold")); break;}
 	}
-	editWidget = new TransactionEditWidget(false, extra_parameters, transaction_type, split, transfer_to, security, security_value_type, budg, this);
+	editWidget = new TransactionEditWidget(false, extra_parameters, transaction_type, split, transfer_to, security, security_value_type, select_security, budg, this);
 	editWidget->transactionsReset();
 	setMainWidget(editWidget);
 }
 void TransactionEditDialog::slotOk() {
-	if(editWidget->validValues()) {
+	if(editWidget->validValues(true)) {
 		KDialogBase::slotOk();
 	}
 }
@@ -1058,12 +1099,7 @@ MultipleTransactionsEditDialog::MultipleTransactionsEditDialog(bool extra_parame
 		else valueButton = new QCheckBox(i18n("Cost:"), mainWidget());
 		valueButton->setChecked(false);
 		editLayout->addWidget(valueButton, 1, 0);
-		valueEdit = new KDoubleSpinBox(0.0, INT_MAX / pow(10, KGlobal::locale()->fracDigits()) - 1.0, 1.0, 0.0, KGlobal::locale()->fracDigits(), mainWidget());
-		if(KGlobal::locale()->positivePrefixCurrencySymbol() && KGlobal::locale()->negativePrefixCurrencySymbol()) {
-			valueEdit->setPrefix(KGlobal::locale()->currencySymbol() + " ");
-		} else {
-			valueEdit->setSuffix(QString(" ") + KGlobal::locale()->currencySymbol());
-		}
+		valueEdit = new EqonomizeValueEdit(false, mainWidget());
 		valueEdit->setEnabled(false);
 		editLayout->addWidget(valueEdit, 1, 1);
 	}
