@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,7 +32,7 @@
 class Budget;
 class Account;
 class KLineEdit;
-class ValueSpinBox;
+class EqonomizeValueEdit;
 class KDateEdit;
 class KComboBox;
 class QPushButton;
@@ -52,7 +52,7 @@ class TransactionEditWidget : public QWidget {
 	
 	public:
 
-		TransactionEditWidget(bool auto_edit, bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *security, SecurityValueDefineType security_value_type, Budget *budg, QWidget *parent = 0, const char *name = 0);
+		TransactionEditWidget(bool auto_edit, bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *security, SecurityValueDefineType security_value_type, bool select_security, Budget *budg, QWidget *parent = 0, const char *name = 0);
 		void setTransaction(Transaction *trans);
 		void setScheduledTransaction(ScheduledTransaction *strans, const QDate &date);
 		void updateFromAccounts(Account *exclude_account = NULL);
@@ -71,9 +71,11 @@ class TransactionEditWidget : public QWidget {
 		void transactionModified(Transaction *trans);
 		bool modifyTransaction(Transaction *trans);
 		Transaction *createTransaction();
-		bool validValues();
+		bool validValues(bool ask_questions = false);
 		QDate date();
+		Security *selectedSecurity();
 		void setMaxShares(double max);
+		void setMaxSharesDate(QDate quotation_date);
 		bool checkAccounts();
 		void currentDateChanged(const QDate &olddate, const QDate &newdate);
 	
@@ -86,11 +88,12 @@ class TransactionEditWidget : public QWidget {
 		Security *security;
 		bool b_autoedit, b_sec, b_extra;
 		bool value_set, shares_set, sharevalue_set;
+		QDate shares_date;
 		
 		QValueVector<Account*> froms, tos;
 		KLineEdit *descriptionEdit, *commentsEdit, *payeeEdit;
-		KComboBox *fromCombo, *toCombo;
-		KDoubleSpinBox *valueEdit, *sharesEdit, *quotationEdit, *quantityEdit;
+		KComboBox *fromCombo, *toCombo, *securityCombo;
+		EqonomizeValueEdit *valueEdit, *sharesEdit, *quotationEdit, *quantityEdit;
 		QPushButton *maxSharesButton;
 		KDateEdit *dateEdit;
 		QWidget *bottom_widget;
@@ -103,6 +106,7 @@ class TransactionEditWidget : public QWidget {
 	public slots:
 
 		void valueChanged(double);
+		void securityChanged();
 		void sharesChanged(double);
 		void quotationChanged(double);
 		void descriptionChanged(const QString&);
@@ -111,34 +115,13 @@ class TransactionEditWidget : public QWidget {
 		
 };
 
-class ValueSpinBox : public KDoubleSpinBox {
-	
-	Q_OBJECT
-			
-	public:
-		
-		ValueSpinBox(QWidget *parent = 0, const char *name = 0);
-		ValueSpinBox(double lower, double upper, double step, double value, int precision = 2, QWidget *parent = 0, const char *name = 0);
-
-		QLineEdit *lineEdit() const;
-		
-	public slots:
-		
-		void selectAll();
-		
-	signals:
-		
-		void returnPressed();
-		
-};
-
 class TransactionEditDialog : public KDialogBase {
 
 	Q_OBJECT
 
 	public:
 
-		TransactionEditDialog(bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *security, SecurityValueDefineType security_value_type, Budget *budg, QWidget *parent);
+		TransactionEditDialog(bool extra_parameters, int transaction_type, bool split, bool transfer_to, Security *security, SecurityValueDefineType security_value_type, bool select_security, Budget *budg, QWidget *parent);
 		TransactionEditWidget *editWidget;
 
 	protected slots:
@@ -172,7 +155,7 @@ class MultipleTransactionsEditDialog : public KDialogBase {
 		QValueVector<Account*> categories;
 		KLineEdit *descriptionEdit, *payeeEdit;
 		KComboBox *categoryCombo;
-		KDoubleSpinBox *valueEdit;
+		EqonomizeValueEdit *valueEdit;
 		KDateEdit *dateEdit;
 
 	protected slots:
