@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,6 +24,7 @@
 
 #include "transactionfilterwidget.h"
 #include "budget.h"
+#include "eqonomizevalueedit.h"
 
 #include <math.h>
 #include <knuminput.h>
@@ -120,11 +121,11 @@ TransactionFilterWidget::TransactionFilterWidget(bool extra_parameters, int tran
 		maxButton = new QCheckBox(i18n("Max cost:"), this);
 	}
 	filterLayout->addWidget(minButton, 1, 0);
-	minEdit = new KDoubleSpinBox(0.0, INT_MAX / pow(10, KGlobal::locale()->fracDigits()) - 1.0, 1.0, 0.0, KGlobal::locale()->fracDigits(), this);
+	minEdit = new EqonomizeValueEdit(false, this);
 	minEdit->setEnabled(false);
 	filterLayout->addWidget(minEdit, 1, 1);
 	filterLayout->addWidget(maxButton, 1, 2);
-	maxEdit = new KDoubleSpinBox(0.0, INT_MAX / pow(10, KGlobal::locale()->fracDigits()) - 1.0, 1.0, 0.0, KGlobal::locale()->fracDigits(), this);
+	maxEdit = new EqonomizeValueEdit(false, this);
 	maxEdit->setEnabled(false);
 	QSizePolicy sp = maxEdit->sizePolicy();
 	sp.setHorData(QSizePolicy::Expanding);
