@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -36,7 +36,7 @@ class QPushButton;
 class QLabel;
 class QCheckBox;
 class QRadioButton;
-class KDoubleSpinBox;
+class EqonomizeValueEdit;
 class QButtonGroup;
 
 class TransactionFilterWidget : public QWidget {
@@ -72,7 +72,7 @@ class TransactionFilterWidget : public QWidget {
 		QValueVector<Account*> froms, tos;
 		KComboBox *fromCombo, *toCombo;
 		QCheckBox *minButton, *maxButton, *dateFromButton;
-		KDoubleSpinBox *minEdit, *maxEdit;
+		EqonomizeValueEdit *minEdit, *maxEdit;
 		KDateEdit *dateFromEdit, *dateToEdit;
 		KLineEdit *descriptionEdit, *payeeEdit;
 		QDate from_date, to_date;
