@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -165,7 +165,7 @@ TransactionListWidget::TransactionListWidget(bool extra_parameters, int transact
 	tabs->setMargin(6);
 	tabs->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
 
-	editWidget = new TransactionEditWidget(true, b_extra, transtype, false, false, NULL, SECURITY_SHARES_AND_QUOTATION, budget, this);
+	editWidget = new TransactionEditWidget(true, b_extra, transtype, false, false, NULL, SECURITY_SHARES_AND_QUOTATION, false, budget, this);
 	editInfoLabel = new QLabel(QString::null, editWidget->bottomWidget());
 	KButtonBox *buttons = new KButtonBox(editWidget->bottomWidget());
 	buttons->addStretch();
@@ -606,11 +606,15 @@ void TransactionListWidget::modifyTransaction() {
 	}
 	TransactionListViewItem *i = (TransactionListViewItem*) selection.getFirst();
 	if(!i) return;
+	if(((TransactionListViewItem*) i)->transaction()->parentSplit()) {
+		editSplitTransaction();
+		return;
+	}
 	if(((TransactionListViewItem*) i)->transaction()->type() == TRANSACTION_TYPE_SECURITY_BUY || ((TransactionListViewItem*) i)->transaction()->type() == TRANSACTION_TYPE_SECURITY_SELL) {
 		editTransaction();
 		return;
 	}
-	if(!editWidget->validValues()) return;
+	if(!editWidget->validValues(true)) return;
 	if(i->scheduledTransaction()) {
 		if(i->scheduledTransaction()->isOneTimeTransaction()) {
 			Transaction *trans = i->scheduledTransaction()->transaction()->copy();
@@ -701,7 +705,7 @@ void TransactionListWidget::removeSplitTransaction() {
 		TransactionListViewItem *i = (TransactionListViewItem*) selection.getFirst();
 		if(i->transaction()->parentSplit()) {
 			SplitTransaction *split = i->transaction()->parentSplit();		
-			if(!KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to delete all (%1) transactions in the selected split transaction?").arg(split->splits.count()))) {
+			if(KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to delete all (%1) transactions in the selected split transaction?").arg(split->splits.count())) == KMessageBox::Cancel) {
 				return;
 			}
 			budget->removeSplitTransaction(split, true);
@@ -735,10 +739,11 @@ void TransactionListWidget::joinTransactions() {
 	TransactionListViewItem *i = (TransactionListViewItem*) selection.first();
 	while(i) {
 		Transaction *trans = i->transaction();
-		if(trans->type() != TRANSACTION_TYPE_SECURITY_BUY && trans->type() != TRANSACTION_TYPE_SECURITY_SELL && (trans->type() != TRANSACTION_TYPE_INCOME || !((Income*) trans)->security())) {
+		if(trans && (!i->scheduledTransaction() && !trans->parentSplit())) {
 			if(!split) {
-				if(trans->fromAccount()->type() == ACCOUNT_TYPE_ASSETS) split = new SplitTransaction(budget, i->transaction()->date(), (AssetsAccount*) trans->fromAccount());
-				else split = new SplitTransaction(budget, i->transaction()->date(), (AssetsAccount*) trans->fromAccount());
+				if((trans->type() == TRANSACTION_TYPE_SECURITY_BUY || trans->type() == TRANSACTION_TYPE_SECURITY_SELL) && ((SecurityTransaction*) trans)->account()->type() == ACCOUNT_TYPE_ASSETS) split = new SplitTransaction(budget, i->transaction()->date(), (AssetsAccount*) ((SecurityTransaction*) trans)->account());
+				else if(trans->fromAccount()->type() == ACCOUNT_TYPE_ASSETS) split = new SplitTransaction(budget, i->transaction()->date(), (AssetsAccount*) trans->fromAccount());
+				else split = new SplitTransaction(budget, i->transaction()->date(), (AssetsAccount*) trans->toAccount());
 			}
 			split->splits.push_back(trans);
 		}
@@ -759,7 +764,7 @@ void TransactionListWidget::removeTransaction() {
 	QPtrList<QListViewItem> selection = transactionsView->selectedItems();
 #endif
 	if(selection.count() > 1) {
-		if(!KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to delete all (%1) selected transactions?").arg(selection.count()))) {
+		if(KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to delete all (%1) selected transactions?").arg(selection.count())) == KMessageBox::Cancel) {
 			return;
 		}
 	}
@@ -848,6 +853,15 @@ void TransactionListWidget::appendFilterScheduledTransaction(ScheduledTransactio
 	}
 }
 
+void TransactionListWidget::onSplitRemoved(SplitTransaction *split) {	
+	TransactionListViewItem *i = (TransactionListViewItem*) transactionsView->firstChild();
+	while(i) {
+		if(i->transaction()->parentSplit() == split) {
+			i->setText(1, i->transaction()->description());	
+		}
+		i = (TransactionListViewItem*) i->nextSibling();
+	}
+}
 void TransactionListWidget::onTransactionAdded(Transaction *trans) {	
 	appendFilterTransaction(trans, true);
 	filterWidget->transactionAdded(trans);
@@ -1129,10 +1143,6 @@ void TransactionListWidget::updateTransactionActions() {
 			b_join = false;
 			break;
 		}		
-		if(trans->type() == TRANSACTION_TYPE_SECURITY_BUY || trans->type() == TRANSACTION_TYPE_SECURITY_SELL || (trans->type() == TRANSACTION_TYPE_INCOME && ((Income*) trans)->security())) {
-			b_join = false;
-			break;
-		}
 		i = (TransactionListViewItem*) selection.next();
 	}
 	SplitTransaction *split = NULL;
