@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2006, 2007 by Niklas Knutsson                           *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -33,6 +33,7 @@ class TransactionEditWidget;
 class QTabWidget;
 class KListView;
 class Transaction;
+class SplitTransaction;
 class ScheduledTransaction;
 class QPushButton;
 class QPopupMenu;
@@ -94,6 +95,7 @@ class TransactionListWidget : public QWidget {
 		void editSplitTransaction();
 		void splitUpTransaction();
 		void joinTransactions();
+		void onSplitRemoved(SplitTransaction*);	
 		void onTransactionAdded(Transaction*);
 		void onTransactionModified(Transaction*, Transaction*);
 		void onTransactionRemoved(Transaction*);
